@@ -120,7 +120,7 @@ class BaseSnatch:
 
     def _format_response(self, data: Dict[Any, Any]) -> BaseData:
         data_obj = self.serializer_class().load(data)
-        data_obj.settings = self.settings
+        data_obj.current_environment = self.settings["current_environment"]
         return data_obj
 
     def _format_error_response(self, error):
@@ -136,7 +136,7 @@ class BaseSnatch:
                 "payload": error.response.json() if hasattr(error, "response") else {},
             }
         )
-        data_obj.settings = self.settings
+        data_obj.current_environment = self.settings["current_environment"]
         return data_obj
 
     def _format_timeout_response(self, url):
@@ -146,7 +146,7 @@ class BaseSnatch:
                 "integration_status": "TIMEOUT",
             }
         )
-        data_obj.settings = self.settings
+        data_obj.current_environment = self.settings["current_environment"]
         return data_obj
 
     def _request_and_create_data(
