@@ -6,7 +6,6 @@ from marshmallow import EXCLUDE, Schema, fields, post_load
 from snatch.base.data import BaseData
 from snatch.base.data_source import BaseSnatch
 from snatch.base.schema import BaseSchema
-from snatch.config import settings
 
 
 @dataclass
@@ -62,6 +61,6 @@ class BoaVistaSerializer(BaseSchema):
 class BoaVista(BaseSnatch):
     default_timeout: int = 60
     default_max_days: int = 180
-    base_url: str = settings["snatch.datasource_boa_vista_url"]
-    authorization_token: str = settings["snatch.boa_vista_secret_token"]
+    base_url_key: str = "snatch.datasource_boa_vista_url"
+    authorization_token_key: str = "snatch.boa_vista_secret_token"
     serializer_class: Type[Schema] = BoaVistaSerializer
