@@ -53,19 +53,18 @@ class SecretManager:
 
     def _get_available_secrets(self) -> List[str]:
         all_secrets = self.client.list_secrets(
-            all_secrets=self.client.list_secrets(
-                MaxResults=100,
-                Filters=[
-                    {
-                        "Key": "name",
-                        "Values": [
-                            "snatch",
-                        ],
-                    },
-                ],
-            )
+            Filters=[
+                {
+                    "Key": "name",
+                    "Values": [
+                        "/datasource/local/snatch",
+                        "/datasource/dev/snatch",
+                        "/datasource/staging/snatch",
+                        "/datasource/production/snatch",
+                    ],
+                },
+            ],
         )
-
         all_keys = [
             secret["Name"]
             for secret in all_secrets["SecretList"]
